CodeMap

Struct CodeMap 

pub struct CodeMap(/* private fields */);
A data structure recording a source code file for position lookup.

Implementations

Source

impl CodeMap

pub fn new(filename: String, source: String) -> CodeMap

Creates an new CodeMap.

pub fn empty_static() -> &'static CodeMap

pub fn id(&self) -> CodeMapId

Only used internally for profiling optimisations

pub fn full_span(&self) -> Span

pub fn file_span(&self, span: Span) -> FileSpan

Gets the file and its line and column ranges represented by a Span.

pub fn filename(&self) -> &str

Gets the name of the file

pub fn byte_at(&self, pos: Pos) -> u8

pub fn find_line(&self, pos: Pos) -> usize

Gets the line number of a Pos.

The lines are 0-indexed (first line is numbered 0)

Panics if pos is not within this file’s span.

pub fn source(&self) -> &str

Gets the full source text of the file

pub fn source_span(&self, span: Span) -> &str

Gets the source text of a Span.

Panics if span is not entirely within this file.

pub fn line_span(&self, line: usize) -> Span

Like line_span_opt but panics if the line number is out of range.

pub fn line_span_trim_newline(&self, line: usize) -> Span

Trim trailing newline if any, including windows, from the line span.

pub fn line_span_opt(&self, line: usize) -> Option<Span>

Gets the span representing a line by line number.

The line number is 0-indexed (first line is numbered 0). The returned span includes the line terminator.

Returns None if the number if out of range.

pub fn resolve_span(&self, span: Span) -> ResolvedSpan

pub fn source_line(&self, line: usize) -> &str

Gets the source text of a line.

The string returned does not include the terminating \r or \n characters.

Panics if the line number is out of range.

pub fn source_line_at_pos(&self, pos: Pos) -> &str